orion.primitives.timeseries\_errors.regression\_errors
======================================================

.. currentmodule:: orion.primitives.timeseries_errors

.. autofunction:: regression_errors